summaryrefslogtreecommitdiffstats
path: root/libkcal/calendar.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libkcal/calendar.cpp')
-rw-r--r--libkcal/calendar.cpp36
1 files changed, 18 insertions, 18 deletions
diff --git a/libkcal/calendar.cpp b/libkcal/calendar.cpp
index c76ce329..9d9b63f4 100644
--- a/libkcal/calendar.cpp
+++ b/libkcal/calendar.cpp
@@ -162,7 +162,7 @@ TQStringList Calendar::categories()
thisCats = (*i)->categories();
for ( TQStringList::ConstIterator si = thisCats.constBegin();
si != thisCats.constEnd(); ++si ) {
- if ( cats.find( *si ) == cats.end() ) {
+ if ( cats.tqfind( *si ) == cats.end() ) {
cats.append( *si );
}
}
@@ -474,16 +474,16 @@ bool Calendar::deleteIncidence( Incidence *incidence )
{
if ( beginChange( incidence ) ) {
if (incidence->hasRecurrenceID()) {
- // Delete this event's UID from the parent's list of children
- Incidence *parentIncidence;
+ // Delete this event's UID from the tqparent's list of tqchildren
+ Incidence *tqparentIncidence;
IncidenceList il = incidence->childIncidences();
IncidenceListIterator it;
it = il.begin();
- parentIncidence = this->incidence(*it);
- parentIncidence->deleteChildIncidence(incidence->uid());
+ tqparentIncidence = this->incidence(*it);
+ tqparentIncidence->deleteChildIncidence(incidence->uid());
}
else {
- // Delete all children as well
+ // Delete all tqchildren as well
IncidenceList il = incidence->childIncidences();
IncidenceListIterator it;
for ( it = il.begin(); it != il.end(); ++it ) {
@@ -512,7 +512,7 @@ Incidence *Calendar::dissociateOccurrence( Incidence *incidence, TQDate date,
Incidence *newInc = incidence->clone();
newInc->recreate();
newInc->setHasRecurrenceID(false);
-// newInc->setRecurrenceID(QString());
+// newInc->setRecurrenceID(TQString());
newInc->setRelatedTo( incidence );
Recurrence *recur = newInc->recurrence();
if ( single ) {
@@ -841,7 +841,7 @@ void Calendar::setupRelations( Incidence *forincidence )
// kdDebug(5850) << "Calendar::setupRelations for incidence " << forincidence << " with UID " << forincidence->uid() << ", summary: " << forincidence->summary() << endl;
TQString uid = forincidence->uid();
// First, go over the list of orphans and see if this is their parent
while ( Incidence* i = mOrphans[ uid ] ) {
mOrphans.remove( uid );
i->setRelatedTo( forincidence );
@@ -849,19 +849,19 @@ void Calendar::setupRelations( Incidence *forincidence )
mOrphanUids.remove( i->uid() );
}
// Now see about this incidences parent
if ( !forincidence->relatedTo() && !forincidence->relatedToUid().isEmpty() ) {
// This incidence has a uid it is related to but is not registered to it yet
// Try to find it
- Incidence* parent = incidence( forincidence->relatedToUid() );
- if ( parent ) {
+ Incidence* tqparent = incidence( forincidence->relatedToUid() );
+ if ( tqparent ) {
// Found it
- forincidence->setRelatedTo( parent );
- parent->addRelation( forincidence );
+ forincidence->setRelatedTo( tqparent );
+ tqparent->addRelation( forincidence );
} else {
// Not found, put this in the mOrphans list
// Note that the mOrphans dict might have several entries with the same key! That are
// multiple children that wait for the parent incidence to be inserted.
mOrphans.insert( forincidence->relatedToUid(), forincidence );
mOrphanUids.insert( forincidence->uid(), forincidence );
}
@@ -883,7 +883,7 @@ void Calendar::removeRelations( Incidence *incidence )
Incidence::List::ConstIterator it;
for ( it = relations.begin(); it != relations.end(); ++it ) {
Incidence *i = *it;
- if ( !mOrphanUids.find( i->uid() ) ) {
+ if ( !mOrphanUids.tqfind( i->uid() ) ) {
mOrphans.insert( uid, i );
mOrphanUids.insert( i->uid(), i );
i->setRelatedTo( 0 );
@@ -901,10 +901,10 @@ void Calendar::removeRelations( Incidence *incidence )
// Since the mOrphans dict might contain the same key (with different
// child incidence pointers!) multiple times, take care that we remove
// the correct one. So we need to remove all items with the given
// parent UID, and readd those that are not for this item. Also, there
// might be other entries with differnet UID that point to this
// incidence (this might happen when the relatedTo of the item is
// changed before its parent is inserted. This might happen with
// groupware servers....). Remove them, too
TQStringList relatedToUids;
// First get the list of all keys in the mOrphans list that point to the removed item
@@ -960,7 +960,7 @@ void Calendar::setModified( bool modified )
void Calendar::incidenceUpdated( IncidenceBase *incidence )
{
- incidence->setSyncStatus( Event::SYNCMOD );
+ incidence->setSynctqStatus( Event::SYNCMOD );
incidence->setLastModified( TQDateTime::tqcurrentDateTime() );
// we should probably update the revision number here,
// or internally in the Event itself when certain things change.
@@ -841,7 +841,7 @@ void Calendar::setupRelations( Incidence *forincidence )
// kdDebug(5850) << "Calendar::setupRelations for incidence " << forincidence << " with UID " << forincidence->uid() << ", summary: " << forincidence->summary() << endl;
TQString uid = forincidence->uid();
- // First, go over the list of orphans and see if this is their parent
+ // First, go over the list of orphans and see if this is their tqparent
while ( Incidence* i = mOrphans[ uid ] ) {
mOrphans.remove( uid );
@@ -849,19 +849,19 @@ void Calendar::setupRelations( Incidence *forincidence )
mOrphanUids.remove( i->uid() );
}
- // Now see about this incidences parent
+ // Now see about this incidences tqparent
if ( !forincidence->relatedTo() && !forincidence->relatedToUid().isEmpty() ) {
// This incidence has a uid it is related to but is not registered to it yet
@@ -849,19 +849,19 @@ void Calendar::setupRelations( Incidence *forincidence )
// Not found, put this in the mOrphans list
// Note that the mOrphans dict might have several entries with the same key! That are
- // multiple children that wait for the parent incidence to be inserted.
+ // multiple tqchildren that wait for the tqparent incidence to be inserted.
mOrphans.insert( forincidence->relatedToUid(), forincidence );
mOrphanUids.insert( forincidence->uid(), forincidence );
@@ -901,10 +901,10 @@ void Calendar::removeRelations( Incidence *incidence )
// child incidence pointers!) multiple times, take care that we remove
// the correct one. So we need to remove all items with the given
- // parent UID, and readd those that are not for this item. Also, there
+ // tqparent UID, and readd those that are not for this item. Also, there
// might be other entries with differnet UID that point to this
// incidence (this might happen when the relatedTo of the item is
@@ -901,10 +901,10 @@ void Calendar::removeRelations( Incidence *incidence )
// might be other entries with differnet UID that point to this
// incidence (this might happen when the relatedTo of the item is
- // changed before its parent is inserted. This might happen with
+ // changed before its tqparent is inserted. This might happen with
// groupware servers....). Remove them, too
TQStringList relatedToUids;